==> 1.0.3.tar.gz: android/src/main/kotlin/com/jarvanmo/rammus/RammusPushIntentService.kt <==
package com.jarvanmo.rammus

import android.content.Context
import android.os.Handler
import android.util.Log
import com.alibaba.sdk.android.push.AliyunMessageIntentService
import com.alibaba.sdk.android.push.notification.CPushMessage

/***
 * Created by mo on 2019-06-25
 * 冷风如刀，以大地为砧板，视众生为鱼肉。
 * 万里飞雪，将穹苍作烘炉，熔万物为白银。
 **/
class RammusPushIntentService : AliyunMessageIntentService() {
    val handler = Handler()

    override fun onNotificationRemoved(context: Context, messageId: String?) {
//        Log.e("TAG","data-2 is $messageId")

        handler.post {
            RammusPushHandler.methodChannel?.invokeMethod("onNotificationRemoved", messageId)
        }
    }

    override fun onNotification(context: Context, title: String?, summary: String?, extras: MutableMap<String, String>?) {
//        Log.e("TAG","data-1 is ${summary}")

//        Context context, String title, String summary, Map<String, String> extraMap)
        handler.post {

            RammusPushHandler.methodChannel?.invokeMethod("onNotification", mapOf(
                    "title" to title,
                    "summary" to summary,
                    "extras" to extras
            ))
        }
    }

    override fun onMessage(context: Context, message: CPushMessage) {
//        Log.e("TAG","data1 is ${message.content}")

        handler.post {
            RammusPushHandler.methodChannel?.invokeMethod("onMessageArrived", mapOf(
                    "appId" to message.appId,
                    "content" to message.content,
                    "messageId" to message.messageId,
                    "title" to message.title,
                    "traceInfo" to message.traceInfo
            ))
        }
    }

    override fun onNotificationOpened(p0: Context?, title: String?, summary: String?, extras: String?) {

//        Log.e("TAG","data2 is $summary")

        handler.post {

            RammusPushHandler.methodChannel?.invokeMethod("onNotificationOpened", mapOf(
                    "title" to title,
                    "summary" to summary,
                    "extras" to extras
            ))
        }
    }

    override fun onNotificationReceivedInApp(p0: Context?, title: String?, summary: String?, extras: MutableMap<String, String>?, openType: Int, openActivity: String?, openUrl: String?) {
//        Log.e("TAG","data3 is $summary")

        handler.post {
            RammusPushHandler.methodChannel?.invokeMethod("onNotificationReceivedInApp", mapOf(
                    "title" to title,
                    "summary" to summary,
                    "extras" to extras,
                    "openType" to openType,
                    "openActivity" to openActivity,
                    "openUrl" to openUrl
            ))
        }
    }

    override fun onNotificationClickedWithNoAction(context: Context, title: String?, summary: String?, extras: String?) {
//        Log.e("TAG","data4 is $summary")

        handler.post {

            RammusPushHandler.methodChannel?.invokeMethod("onNotificationClickedWithNoAction", mapOf(
                    "title" to title,
                    "summary" to summary,
                    "extras" to extras
            ))
        }
    }
}

==> 1.2.0.tar.gz: android/src/main/kotlin/com/jarvanmo/rammus/RammusPushIntentService.kt <==
package com.jarvanmo.rammus

import android.content.Context
import android.os.Handler
import android.util.Log
import com.alibaba.sdk.android.push.AliyunMessageIntentService
import com.alibaba.sdk.android.push.notification.CPushMessage

/***
 * Created by mo on 2019-06-25
 * 冷风如刀，以大地为砧板，视众生为鱼肉。
 * 万里飞雪，将穹苍作烘炉，熔万物为白银。
 **/

class RammusPushIntentService : AliyunMessageIntentService() {
    private val handler = Handler()

    override fun onNotificationRemoved(context: Context, messageId: String?) {
        Log.d("RammusPushIntentService","onNotificationRemoved messageId is $messageId")

        handler.postDelayed( {
            RammusPushHandler.methodChannel?.invokeMethod("onNotificationRemoved", messageId)
        },1500)
    }

    override fun onNotification(context: Context, title: String?, summary: String?, extras: MutableMap<String, String>?) {
        Log.d("RammusPushIntentService","onNotification title is $title, summary is $summary, extras: $extras")
        handler.postDelayed({

            RammusPushHandler.methodChannel?.invokeMethod("onNotification", mapOf(
                    "title" to title,
                    "summary" to summary,
                    "extras" to extras
            ))
        },1500)
    }

    override fun onMessage(context: Context, message: CPushMessage) {
        Log.d("RammusPushIntentService","onMessage title is ${message.title}, messageId is ${message.messageId}, content is ${message.content}")
        handler.postDelayed( {
            RammusPushHandler.methodChannel?.invokeMethod("onMessageArrived", mapOf(
                    "appId" to message.appId,
                    "content" to message.content,
                    "messageId" to message.messageId,
                    "title" to message.title,
                    "traceInfo" to message.traceInfo
            ))
        },1500)
    }

    override fun onNotificationOpened(p0: Context?, title: String?, summary: String?, extras: String?) {

        Log.d("RammusPushIntentService","onNotificationOpened title is $title, summary is $summary, extras: $extras")
        handler.postDelayed({
            RammusPushHandler.methodChannel?.invokeMethod("onNotificationOpened", mapOf(
                    "title" to title,
                    "summary" to summary,
                    "extras" to extras
            ))
        },1500)
    }

    override fun onNotificationReceivedInApp(p0: Context?, title: String?, summary: String?, extras: MutableMap<String, String>?, openType: Int, openActivity: String?, openUrl: String?) {
        Log.d("RammusPushIntentService","onNotificationReceivedInApp title is $title, summary is $summary, extras: $extras")
        handler.postDelayed( {
            RammusPushHandler.methodChannel?.invokeMethod("onNotificationReceivedInApp", mapOf(
                    "title" to title,
                    "summary" to summary,
                    "extras" to extras,
                    "openType" to openType,
                    "openActivity" to openActivity,
                    "openUrl" to openUrl
            ))
        },1500)
    }

    override fun onNotificationClickedWithNoAction(context: Context, title: String?, summary: String?, extras: String?) {
        Log.d("RammusPushIntentService","onNotificationClickedWithNoAction title is $title, summary is $summary, extras: $extras")
        handler.postDelayed(  {
            RammusPushHandler.methodChannel?.invokeMethod("onNotificationClickedWithNoAction", mapOf(
                    "title" to title,
                    "summary" to summary,
                    "extras" to extras
            ))
        }, 1500)
    }
}
